"""
A collection of general purpose reusable utilities.
"""


def version():
    return "0.3.1"
